@@ -2,9 +2,9 @@
 require File.expand_path("../helper", __FILE__)
 require "stringio"
 
-class TestRakeExtension < Rake::TestCase
+class TestRakeExtension < Rake::TestCase # :nodoc:
 
-  module Redirect
+  module Redirect # :nodoc:
     def error_redirect
       old_err = $stderr
       result = StringIO.new
@@ -16,7 +16,7 @@ class TestRakeExtension < Rake::TestCase
     end
   end
 
-  class Sample
+  class Sample # :nodoc:
     extend Redirect
 
     def duplicate_method
