@@ -383,7 +383,7 @@ class TestRakeFileList < Rake::TestCase # :nodoc:
   def test_egrep_with_output
     files = FileList["*.txt"]
 
-    out, = capture_io do
+    out, = capture_output do
       files.egrep(/XYZZY/)
     end
 
@@ -404,7 +404,7 @@ class TestRakeFileList < Rake::TestCase # :nodoc:
   def test_egrep_with_error
     files = FileList["*.txt"]
 
-    _, err = capture_io do
+    _, err = capture_output do
       files.egrep(/XYZZY/) do |fn, ln, line |
         raise "_EGREP_FAILURE_"
       end
@@ -496,7 +496,7 @@ class TestRakeFileList < Rake::TestCase # :nodoc:
     assert_equal ["a", "b", "c"], d
   end
 
-  if RUBY_VERSION < '2.7'
+  if RUBY_VERSION < "2.7"
     def test_dup_and_clone_replicate_taint
       a = FileList["a", "b", "c"]
       a.taint
@@ -519,7 +519,8 @@ class TestRakeFileList < Rake::TestCase # :nodoc:
     a = FileList["a", "b", "c"]
     a.freeze
     c = a.clone
-    assert_raises(TypeError, RuntimeError) do
+    error_class = defined?(FrozenError) ? FrozenError : RuntimeError
+    assert_raises(error_class) do
       c << "more"
     end
   end
