@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 require File.expand_path("../helper", __FILE__)
 
-class TestLinkedList < Rake::TestCase
+class TestLinkedList < Rake::TestCase # :nodoc:
   include Rake
 
   def test_empty_list
